@@ -11,7 +11,7 @@ use warnings;
 
 no warnings qw( threads recursion uninitialized );
 
-our $VERSION = '1.819';
+our $VERSION = '1.820';
 
 ## no critic (BuiltinFunctions::ProhibitStringyEval)
 ## no critic (Subroutines::ProhibitSubroutinePrototypes)
@@ -279,7 +279,7 @@ sub run (&@) {
 
    ## -------------------------------------------------------------------------
 
-   MCE::_save_state();
+   MCE::_save_state($_MCE->{$_pid});
 
    if (!defined $_prev_c->{$_pid} || $_prev_c->{$_pid} != $_code) {
       $_MCE->{$_pid}->shutdown() if (defined $_MCE->{$_pid});
@@ -445,7 +445,7 @@ MCE::Map - Parallel map model similar to the native map function
 
 =head1 VERSION
 
-This document describes MCE::Map version 1.819
+This document describes MCE::Map version 1.820
 
 =head1 SYNOPSIS
 
